==> google_applovin_unity_ads-2.3.14.tar.gz: example/android/app/src/main/kotlin/com/btcpiyush/ads/google_applovin_unity_ads_example/CustomGeoSdk.kt <==
package com.btcpiyush.ads.google_applovin_unity_ads_example

import android.util.Log
import android.widget.Toast
import com.appharbr.sdk.configuration.AHSdkConfiguration
import com.appharbr.sdk.engine.*
import com.appharbr.sdk.engine.adformat.AdFormat
import com.appharbr.sdk.engine.listeners.AHListener
import com.appharbr.sdk.engine.listeners.OnAppHarbrInitializationCompleteListener
import com.applovin.mediation.MaxAd
import com.applovin.mediation.MaxAdListener
import com.applovin.mediation.MaxRewardedAdListener
import com.applovin.mediation.ads.MaxAdView
import com.applovin.mediation.ads.MaxInterstitialAd
import com.applovin.mediation.ads.MaxRewardedAd
import com.btcpiyush.ads.google_applovin_unity_ads.GoogleApplovinUnityAdsPlugin.GeoedgeSdkFactory
import io.flutter.embedding.android.FlutterActivity
import java.util.*

data class CustomGeoSdk(val activity: FlutterActivity) : GeoedgeSdkFactory {

    override fun initializeGeoSdk(geoedgeSdkKey: String?, timeoutInSeconds: Long) {
        if (geoedgeSdkKey.isNullOrEmpty()) {
            return@initializeGeoSdk
        }
        Log.e( "initializeGeoSdk: ", " ========== = = = = =  =   timeoutInSeconds    ------    ${timeoutInSeconds}")
        val ahSdkConfiguration = AHSdkConfiguration.Builder(geoedgeSdkKey)
            .withMuteAd(true)
            .withInterstitialAdTimeLimit(timeoutInSeconds)
            .build()

        AppHarbr.initialize(activity.applicationContext,
            ahSdkConfiguration,
            object : OnAppHarbrInitializationCompleteListener {
                override fun onSuccess() {
                    Toast.makeText(
                        activity,
                        "AppHarbr SDK Initialized Successfully",
                        Toast.LENGTH_SHORT
                    ).show()
                    Log.e("LOG", "AppHarbr SDK Initialized Successfully")
                }

                override fun onFailure(reason: InitializationFailureReason) {
                    Toast.makeText(
                        activity,
                        "AppHarbr SDK Initialized onFailure",
                        Toast.LENGTH_SHORT
                    ).show()
                    Log.e(
                        "LOG",
                        "AppHarbr SDK Initialization Failed: " + reason.readableHumanReason
                    )
                }
            })
    }

    override fun addBannerAd(maxAdView: MaxAdView?) {
        val ahListener =
            AHListener { view: Any?, unitId: String?, adFormat: AdFormat?, reasons: Array<AdBlockReason?>? ->
                Log.e(
                    "LOG",
                    "AppHarbr - onAdBlocked for: $unitId, AppHarbr Banner reason: " + Arrays.toString(
                        reasons
                    )
                )
            }

        maxAdView?.let {
            AppHarbr.addBannerView(AdSdk.MAX, maxAdView, activity.lifecycle, ahListener)
        }

    }

    override fun isGeoAdShow(maxAdView: MaxAd, adId: String): Boolean {
        val result = AppHarbr.shouldBlockNativeAd(AdSdk.MAX, maxAdView, adId)
        return result.adStateResult !== AdStateResult.BLOCKED
    }

    override fun setGeoIntraListener(
        mInterstitialAppLovinAd: MaxInterstitialAd,
        mInterstitialAppLovinCallback: MaxAdListener
    ) {
        val ahListener =
            AHListener { view: Any?, unitId: String?, adFormat: AdFormat?, reasons: Array<AdBlockReason?>? -> }

        val callback = AppHarbr.addInterstitial(
            AdSdk.MAX,
            mInterstitialAppLovinAd,
            mInterstitialAppLovinCallback,
            activity.lifecycle,
            ahListener
        )

        mInterstitialAppLovinAd.setListener(callback)
    }

    override fun setGeoRewardListener(
        mRewardAppLovinAd: MaxRewardedAd,
        mRewardAppLovinCallback: MaxRewardedAdListener
    ) {
        val ahListener =
            AHListener { _: Any?, unitId: String?, _: AdFormat?, reasons: Array<AdBlockReason?>? -> }

        val ahWrapperListener: MaxRewardedAdListener? = AppHarbr.addRewardedAd(
                AdSdk.MAX,
                mRewardAppLovinAd,
                mRewardAppLovinCallback,
                activity.lifecycle,
                ahListener
            )

        //Set ahWrapperListener and load Ad
        mRewardAppLovinAd.setListener(ahWrapperListener)
    }

    override fun isGeoAdShow(mInterstitialAppLovinAd: MaxInterstitialAd): Boolean {
        if (!mInterstitialAppLovinAd.isReady) {
            return false
        }
        return AppHarbr.getInterstitialState(mInterstitialAppLovinAd) != AdStateResult.BLOCKED
    }

    override fun isGeoAdShow(mRewardAppLovinAd: MaxRewardedAd): Boolean {
        if (!mRewardAppLovinAd.isReady) {
            return false
        }
        return AppHarbr.getRewardedState(mRewardAppLovinAd) != AdStateResult.BLOCKED
    }

}

==> google_applovin_unity_ads-2.3.15.tar.gz: example/android/app/src/main/kotlin/com/btcpiyush/ads/google_applovin_unity_ads_example/CustomGeoSdk.kt <==
package com.btcpiyush.ads.google_applovin_unity_ads_example

import android.util.Log
import android.widget.Toast
import com.appharbr.sdk.configuration.AHSdkConfiguration
import com.appharbr.sdk.engine.*
import com.appharbr.sdk.engine.adformat.AdFormat
import com.appharbr.sdk.engine.listeners.AHListener
import com.appharbr.sdk.engine.listeners.OnAppHarbrInitializationCompleteListener
import com.applovin.mediation.MaxAd
import com.applovin.mediation.MaxAdListener
import com.applovin.mediation.MaxRewardedAdListener
import com.applovin.mediation.ads.MaxAdView
import com.applovin.mediation.ads.MaxInterstitialAd
import com.applovin.mediation.ads.MaxRewardedAd
import com.btcpiyush.ads.google_applovin_unity_ads.GoogleApplovinUnityAdsPlugin.GeoedgeSdkFactory
import io.flutter.embedding.android.FlutterActivity
import java.util.*

data class CustomGeoSdk(val activity: FlutterActivity) : GeoedgeSdkFactory {

    override fun initializeGeoSdk(geoedgeSdkKey: String?, timeoutInSeconds: Int) {
        if (geoedgeSdkKey.isNullOrEmpty()) {
            return@initializeGeoSdk
        }
        Log.e( "initializeGeoSdk: ", " ========== = = = = =  =   timeoutInSeconds    ------    ${timeoutInSeconds}")
        val ahSdkConfiguration = AHSdkConfiguration.Builder(geoedgeSdkKey)
            .withMuteAd(true)
            .withInterstitialAdTimeLimit(timeoutInSeconds)
            .build()

        AppHarbr.initialize(activity.applicationContext,
            ahSdkConfiguration,
            object : OnAppHarbrInitializationCompleteListener {
                override fun onSuccess() {
                    Toast.makeText(
                        activity,
                        "AppHarbr SDK Initialized Successfully",
                        Toast.LENGTH_SHORT
                    ).show()
                    Log.e("LOG", "AppHarbr SDK Initialized Successfully")
                }

                override fun onFailure(reason: InitializationFailureReason) {
                    Toast.makeText(
                        activity,
                        "AppHarbr SDK Initialized onFailure",
                        Toast.LENGTH_SHORT
                    ).show()
                    Log.e(
                        "LOG",
                        "AppHarbr SDK Initialization Failed: " + reason.readableHumanReason
                    )
                }
            })
    }

    override fun addBannerAd(maxAdView: MaxAdView?) {
        val ahListener =
            AHListener { view: Any?, unitId: String?, adFormat: AdFormat?, reasons: Array<AdBlockReason?>? ->
                Log.e(
                    "LOG",
                    "AppHarbr - onAdBlocked for: $unitId, AppHarbr Banner reason: " + Arrays.toString(
                        reasons
                    )
                )
            }

        maxAdView?.let {
            AppHarbr.addBannerView(AdSdk.MAX, maxAdView, activity.lifecycle, ahListener)
        }

    }

    override fun isGeoAdShow(maxAdView: MaxAd, adId: String): Boolean {
        val result = AppHarbr.shouldBlockNativeAd(AdSdk.MAX, maxAdView, adId)
        return result.adStateResult !== AdStateResult.BLOCKED
    }

    override fun setGeoIntraListener(
        mInterstitialAppLovinAd: MaxInterstitialAd,
        mInterstitialAppLovinCallback: MaxAdListener
    ) {
        val ahListener =
            AHListener { view: Any?, unitId: String?, adFormat: AdFormat?, reasons: Array<AdBlockReason?>? -> }

        val callback = AppHarbr.addInterstitial(
            AdSdk.MAX,
            mInterstitialAppLovinAd,
            mInterstitialAppLovinCallback,
            activity.lifecycle,
            ahListener
        )

        mInterstitialAppLovinAd.setListener(callback)
    }

    override fun setGeoRewardListener(
        mRewardAppLovinAd: MaxRewardedAd,
        mRewardAppLovinCallback: MaxRewardedAdListener
    ) {
        val ahListener =
            AHListener { _: Any?, unitId: String?, _: AdFormat?, reasons: Array<AdBlockReason?>? -> }

        val ahWrapperListener: MaxRewardedAdListener? = AppHarbr.addRewardedAd(
                AdSdk.MAX,
                mRewardAppLovinAd,
                mRewardAppLovinCallback,
                activity.lifecycle,
                ahListener
            )

        //Set ahWrapperListener and load Ad
        mRewardAppLovinAd.setListener(ahWrapperListener)
    }

    override fun isGeoAdShow(mInterstitialAppLovinAd: MaxInterstitialAd): Boolean {
        if (!mInterstitialAppLovinAd.isReady) {
            return false
        }
        return AppHarbr.getInterstitialState(mInterstitialAppLovinAd) != AdStateResult.BLOCKED
    }

    override fun isGeoAdShow(mRewardAppLovinAd: MaxRewardedAd): Boolean {
        if (!mRewardAppLovinAd.isReady) {
            return false
        }
        return AppHarbr.getRewardedState(mRewardAppLovinAd) != AdStateResult.BLOCKED
    }

}
